.. include:: abbreviation.txt

.. _reference-manual-page:

===================
 API Documentation
===================

This is the API documentation for the PyMetrology library.

.. warning:: The API documentation is automatically generated from the docstrings in the source
  using the |Sphinx| tool.  This way to produce the documentation is know to be perfectible
  actually, but not too bad.

Contents:

.. toctree::
  :maxdepth: 2

  api/PyMetrology

Indexes
-------

  * :ref:`genindex`
  * :ref:`modindex`

..  * :ref:`search`

.. End

